LinuxError class

Inheritance

Constructors

LinuxError([String? description, String? method, int? errno])
factory

Properties

errorCode → int
Error code supplied by the operating system.
finalinherited
hashCode → int
The hash code for this object.
no setterinherited
message → String
Error message supplied by the operating system. This will be empty if no message is associated with the error.
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
Converts an OSError object to a string representation.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited